package com.qmth.cqb.paper.web;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import cn.com.qmth.examcloud.common.uac.entity.AccessUser;

import com.qmth.cqb.paper.model.PaperDetailStructBlueprint;
import com.qmth.cqb.paper.service.PaperDetailStructBlueprintService;

/**
 * @describle 蓝图试卷结构大题 PaperDetailStructBlueprintController
 * @author weiwenhai
 * @date   2017.11.20
 */
@Controller
@RequestMapping("${api_cqb}/")
public class PaperDetailStructBlueprintController {

	@Autowired
	private PaperDetailStructBlueprintService paperDetailStructBlueprintService;
	
	@ApiOperation(value="根据蓝图试卷结构id查询所有大题", notes="不带分页")
	@GetMapping(value="/paperDetailStructBlueprint/all/{paperStructBlueprintId}")
	public ResponseEntity<Object> findAll(HttpServletRequest request, @PathVariable Long paperStructBlueprintId){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser == null){
			return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
		}
		List<PaperDetailStructBlueprint> paperDetailStructBlueprints = paperDetailStructBlueprintService.findAll(paperStructBlueprintId);
		return new ResponseEntity<Object>(paperDetailStructBlueprints,HttpStatus.OK);
	}
	
	@ApiOperation(value="查询新增的大题，无试卷结构id", notes="不带分页")
	@GetMapping(value="/paperDetailStructBlueprint/all")
	public ResponseEntity<Object> findSaveAll(HttpServletRequest request){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser == null){
			return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
		}
		List<PaperDetailStructBlueprint> paperDetailStructBlueprints = paperDetailStructBlueprintService.findSaveAll(accessUser.getUserId(), null);
		return new ResponseEntity<Object>(paperDetailStructBlueprints,HttpStatus.OK);
	}
	
	@ApiOperation(value="保存新增的单个大题", notes="保存新增的单个大题")
	@PostMapping(value="/paperDetailStructBlueprint/save")
	public ResponseEntity<Object> saveSingle(HttpServletRequest request,@RequestBody PaperDetailStructBlueprint paperDetailStructBlueprint){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser == null){
			return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
		}
		//paperDetailStructBlueprint.setType("specifics");//细节
		paperDetailStructBlueprint.setUserId(accessUser.getUserId());
		paperDetailStructBlueprintService.saveSingle(paperDetailStructBlueprint);
		return new ResponseEntity<Object>(HttpStatus.OK);
	}
	
	@ApiOperation(value="保存修改的单个大题", notes="保存修改的单个大题")
	@PutMapping(value="/paperDetailStructBlueprint/update")
	public ResponseEntity<Object> updateSingle(HttpServletRequest request,@RequestBody PaperDetailStructBlueprint paperDetailStructBlueprint){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser == null){
			return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
		}
		paperDetailStructBlueprint.setUserId(accessUser.getUserId());
		paperDetailStructBlueprintService.saveSingle(paperDetailStructBlueprint);
		return new ResponseEntity<Object>(HttpStatus.OK);
	}
	
	@ApiOperation(value="删除单个大题", notes="删除单个大题")
	@DeleteMapping(value="/paperDetailStructBlueprint/delete/{id}")
	public ResponseEntity<Object> deleteSingle(HttpServletRequest request,@PathVariable Long id){
		AccessUser accessUser = (AccessUser) request.getAttribute("accessUser");
		if(accessUser == null){
			return new ResponseEntity<Object>(HttpStatus.NOT_FOUND);
		}
		paperDetailStructBlueprintService.deleteSingle(id);
		return new ResponseEntity<Object>(HttpStatus.OK);
	}
}
